{% extends "registration/base.html" %}
{% load common i18n %}

{% block content %}
	<h1>{% block page_title %}{% if validlink %}{% trans "Enter new password" %}{% else %}{% trans "Password reset unsuccessful" %}{% endif %}{% endblock %}</h1>

	{% if validlink %}
		<p>{% trans "Please enter your new password twice so we can verify you typed it in correctly." %}</p>

		<form action="" method="post">
			{% csrf_token %}

			{% field form.new_password1 %}
			{% field form.new_password2 %}

			<div class="btn-group">
				<button type="submit">
					<i class="fa fa-play-circle"></i>
					{% trans "Change my password" %}
				</button>
			</div>
		</form>
	{% else %}
		<p>{% trans "The password reset link was invalid, possibly because it has already been used. Please request a new password reset." %}</p>
	{% endif %}
{% endblock %}
