{% extends "competition/rankpoints_base.html" %}
{% load i18n %}

{% block content %}
	{% trans "Ranking" as title %}
	<h1>{{ node|default:title }}</h1>

	<div class="cms">
		{% for content in node.contents.all %}
			<div>
				{{ content.copy|safe }}
			</div>
		{% endfor %}
	</div>

	<ul>
		{% for d in date_list %}
			<li><a href="{% url 'ranking:day' year=d.year month=d|date:"b" day=d|date:"j" %}">{{ d }}</a></li>
		{% endfor %}
	</ul>
{% endblock %}
