# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-09-27 21:16
from __future__ import unicode_literals

import django.contrib.postgres.fields
import django.db.models.deletion
import touchtechnology.common.db.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('competition', '0025_matchvideo_baseline'),
    ]

    operations = [
        migrations.AddField(
            model_name='match',
            name='videos',
            field=django.contrib.postgres.fields.ArrayField(base_field=models.URLField(), null=True, size=None),
        ),
        migrations.AlterField(
            model_name='matchvideo',
            name='match',
            field=touchtechnology.common.db.models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='competition.Match'),
        ),
    ]
