{% extends "touchtechnology/admin/base.html" %}

{% block mainnav %}{% endblock %}

{% block full_content %}
	<hr class="spacer-md">
	<hr class="spacer-xs">

	<div class="error-container">
		<div class="error-code">{% block error-code %}{% endblock %}</div> <!-- /.error-code -->

		<div class="error-details">
			{% block error-details %}{% endblock %}

			{% block search-form %}
				<form action="#" class="form">
					<div class="input-group">
						<input type="text" class="form-control" placeholder="Search...">
						<span class="input-group-btn">
							<button class="btn btn-secondary" type="button">
								<i class="fa fa-search"></i>
							</button>
						</span>
					</div><!-- /input-group -->
				</form>
			{% endblock %}
		</div> <!-- /.error-details -->
	</div>
{% endblock %}
