{% extends "touchtechnology/news/base.html" %}
{% load i18n %}

{% block page_title %}{% trans "News archive" %}{% endblock %}

{% block content %}
	<h1>{% trans "News archive" %}</h1>

	{% block archive_info %}{% endblock %}
{% endblock %}
