{% extends "mvp/list.inc.html" %}
{% load i18n %}

{% block table-headings %}
	<th>{% trans "ID" %}</th>
	<th>{% trans "Date" %}</th>
	<th>{% trans "Time" %}</th>
	<th>{% trans "Home Team" %}</th>
	<th>{% trans "Away Team" %}</th>
	<th>{% trans "Videos" %}</th>
{% endblock %}

{% block table-columns %}
	{% trans "TBC" as tbc context "to be confirmed" %}
	<td>
		{% if change_perm in object_perms %}
			<a href="{{ obj.urls.edit }}">{{ obj.label|default:obj.pk }}</a>&nbsp;
		{% else %}
			<span>{{ obj.label|default:obj.pk }}</span>
		{% endif %}
	</td>
	<td>{{ obj.date|default_if_none:tbc }}</td>
	<td>{{ obj.time|default_if_none:tbc }}</td>
	<td>{{ obj.get_home_team }}</td>
	<td>{{ obj.get_away_team }}</td>
	<td>{{ obj.videos|length }}</td>
{% endblock %}

{% block empty-row-colspan %}7{% endblock %}
